# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: events.proto
# plugin: python-betterproto
from dataclasses import dataclass
from datetime import datetime
from typing import (
    Dict,
    List,
)

import betterproto
import betterproto.lib.google.protobuf as betterproto_lib_google_protobuf


@dataclass(eq=False, repr=False)
class CloudEvent(betterproto.Message):
    id: str = betterproto.string_field(1)
    """Required Attributes"""

    source: str = betterproto.string_field(2)
    spec_version: str = betterproto.string_field(3)
    type: str = betterproto.string_field(4)
    attributes: Dict[str, "CloudEventCloudEventAttributeValue"] = betterproto.map_field(
        5, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )
    """Optional & Extension Attributes"""

    binary_data: bytes = betterproto.bytes_field(6, group="data")
    text_data: str = betterproto.string_field(7, group="data")
    proto_data: "betterproto_lib_google_protobuf.Any" = betterproto.message_field(
        8, group="data"
    )


@dataclass(eq=False, repr=False)
class CloudEventCloudEventAttributeValue(betterproto.Message):
    ce_boolean: bool = betterproto.bool_field(1, group="attr")
    ce_integer: int = betterproto.int32_field(2, group="attr")
    ce_string: str = betterproto.string_field(3, group="attr")
    ce_bytes: bytes = betterproto.bytes_field(4, group="attr")
    ce_uri: str = betterproto.string_field(5, group="attr")
    ce_uri_ref: str = betterproto.string_field(6, group="attr")
    ce_timestamp: datetime = betterproto.message_field(7, group="attr")


@dataclass(eq=False, repr=False)
class CloudEventBatch(betterproto.Message):
    events: List["CloudEvent"] = betterproto.message_field(1)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: sigstore_trustroot.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import List

import betterproto

from ...common import v1 as __common_v1__


@dataclass(eq=False, repr=False)
class TransparencyLogInstance(betterproto.Message):
    """
    TransparencyLogInstance describes the immutable parameters from a
    transparency log. See https://www.rfc-editor.org/rfc/rfc9162.html#name-log-
    parameters for more details. The included parameters are the minimal set
    required to identify a log, and verify an inclusion proof/promise.
    """

    base_url: str = betterproto.string_field(1)
    """The base URL at which can be used to URLs for the client."""

    hash_algorithm: "__common_v1__.HashAlgorithm" = betterproto.enum_field(2)
    """The hash algorithm used for the Merkle Tree."""

    public_key: "__common_v1__.PublicKey" = betterproto.message_field(3)
    """
    The public key used to verify signatures generated by the log. This
    attribute contains the signature algorithm used by the log.
    """

    log_id: "__common_v1__.LogId" = betterproto.message_field(4)
    """The unique identifier for this transparency log."""


@dataclass(eq=False, repr=False)
class CertificateAuthority(betterproto.Message):
    """
    CertificateAuthority enlists the information required to identify which CA
    to use and perform signature verification.
    """

    subject: "__common_v1__.DistinguishedName" = betterproto.message_field(1)
    """
    The root certificate MUST be self-signed, and so the subject and issuer are
    the same.
    """

    uri: str = betterproto.string_field(2)
    """The URI at which the CA can be accessed."""

    cert_chain: "__common_v1__.X509CertificateChain" = betterproto.message_field(3)
    """The certificate chain for this CA."""

    valid_for: "__common_v1__.TimeRange" = betterproto.message_field(4)
    """
    The time the *entire* chain was valid. This is at max the longest interval
    when *all* certificates in the chain were valid, but it MAY be shorter.
    Clients MUST check timestamps against *both* the `valid_for` time range
    *and* the entire certificate chain. The TimeRange should be considered
    valid *inclusive* of the endpoints.
    """


@dataclass(eq=False, repr=False)
class TrustedRoot(betterproto.Message):
    """
    TrustedRoot describes the client's complete set of trusted entities. How
    the TrustedRoot is populated is not specified, but can be a combination of
    many sources such as TUF repositories, files on disk etc. The TrustedRoot
    is not meant to be used for any artifact verification, only to capture the
    complete/global set of trusted verification materials. When verifying an
    artifact, based on the artifact and policies, a selection of
    keys/authorities are expected to be extracted and provided to the
    verification function. This way the set of keys/authorities can be kept to
    a minimal set by the policy to gain better control over what signatures
    that are allowed. The embedded transparency logs, CT logs, CAs and TSAs
    MUST include any previously used instance -- otherwise signatures made in
    the past cannot be verified. The currently used instances MUST NOT have
    their 'end' timestamp set in their 'valid_for' attribute for easy
    identification. All the listed instances SHOULD be sorted by the
    'valid_for' in ascending order, that is, the oldest instance first and the
    current instance last.
    """

    media_type: str = betterproto.string_field(1)
    """MUST be application/vnd.dev.sigstore.trustedroot+json;version=0.1"""

    tlogs: List["TransparencyLogInstance"] = betterproto.message_field(2)
    """A set of trusted Rekor servers."""

    certificate_authorities: List["CertificateAuthority"] = betterproto.message_field(3)
    """
    A set of trusted certificate authorities (e.g Fulcio), and any intermediate
    certificates they provide. If a CA is issuing multiple intermediate
    certificate, each combination shall be represented as separate chain. I.e,
    a single root cert may appear in multiple chains but with different
    intermediate and/or leaf certificates. The certificates are intended to be
    used for verifying artifact signatures.
    """

    ctlogs: List["TransparencyLogInstance"] = betterproto.message_field(4)
    """A set of trusted certificate transparency logs."""

    timestamp_authorities: List["CertificateAuthority"] = betterproto.message_field(5)
    """A set of trusted timestamping authorities."""



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: envelope.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import List

import betterproto


@dataclass(eq=False, repr=False)
class Envelope(betterproto.Message):
    """An authenticated message of arbitrary type."""

    payload: bytes = betterproto.bytes_field(1)
    """
    Message to be signed. (In JSON, this is encoded as base64.) REQUIRED.
    """

    payload_type: str = betterproto.string_field(2)
    """String unambiguously identifying how to interpret payload. REQUIRED."""

    signatures: List["Signature"] = betterproto.message_field(3)
    """
    Signature over:     PAE(type, payload) Where PAE is defined as: PAE(type,
    payload) = "DSSEv1" + SP + LEN(type) + SP + type + SP + LEN(payload) + SP +
    payload +               = concatenation SP              = ASCII space
    [0x20] "DSSEv1"        = ASCII [0x44, 0x53, 0x53, 0x45, 0x76, 0x31] LEN(s)
    = ASCII decimal encoding of the byte length of s, with no leading zeros
    REQUIRED (length >= 1).
    """


@dataclass(eq=False, repr=False)
class Signature(betterproto.Message):
    sig: bytes = betterproto.bytes_field(1)
    """Signature itself. (In JSON, this is encoded as base64.) REQUIRED."""

    keyid: str = betterproto.string_field(2)
    """
    *Unauthenticated* hint identifying which public key was used. OPTIONAL.
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: sigstore_rekor.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import List

import betterproto

from ...common import v1 as __common_v1__


@dataclass(eq=False, repr=False)
class KindVersion(betterproto.Message):
    """KindVersion contains the entry's kind and api version."""

    kind: str = betterproto.string_field(1)
    """
    Kind is the type of entry being stored in the log. See here for a list:
    https://github.com/sigstore/rekor/tree/main/pkg/types
    """

    version: str = betterproto.string_field(2)
    """The specific api version of the type."""


@dataclass(eq=False, repr=False)
class Checkpoint(betterproto.Message):
    """
    The checkpoint contains a signature of the tree head (root hash), size of
    the tree, the transparency log's unique identifier (log ID), hostname and
    the current time. The result is a string, the format is described here
    https://github.com/transparency-dev/formats/blob/main/log/README.md The
    details are here https://github.com/sigstore/rekor/blob/a6e58f72b6b18cc06ce
    fe61808efd562b9726330/pkg/util/signed_note.go#L114 The signature has the
    same format as InclusionPromise.signed_entry_timestamp. See below for more
    details.
    """

    envelope: str = betterproto.string_field(1)


@dataclass(eq=False, repr=False)
class InclusionProof(betterproto.Message):
    """
    InclusionProof is the proof returned from the transparency log. Can be used
    for offline or online verification against the log.
    """

    log_index: int = betterproto.int64_field(1)
    """The index of the entry in the tree it was written to."""

    root_hash: bytes = betterproto.bytes_field(2)
    """
    The hash digest stored at the root of the merkle tree at the time the proof
    was generated.
    """

    tree_size: int = betterproto.int64_field(3)
    """The size of the merkle tree at the time the proof was generated."""

    hashes: List[bytes] = betterproto.bytes_field(4)
    """
    A list of hashes required to compute the inclusion proof, sorted in order
    from leaf to root. Note that leaf and root hashes are not included. The
    root hash is available separately in this message, and the leaf hash should
    be calculated by the client.
    """

    checkpoint: "Checkpoint" = betterproto.message_field(5)
    """
    Signature of the tree head, as of the time of this proof was generated. See
    above info on 'Checkpoint' for more details.
    """


@dataclass(eq=False, repr=False)
class InclusionPromise(betterproto.Message):
    """
    The inclusion promise is calculated by Rekor. It's calculated as a
    signature over a canonical JSON serialization of the persisted entry, the
    log ID, log index and the integration timestamp. See https://github.com/sig
    store/rekor/blob/a6e58f72b6b18cc06cefe61808efd562b9726330/pkg/api/entries.g
    o#L54 The format of the signature depends on the transparency log's public
    key. If the signature algorithm requires a hash function and/or a signature
    scheme (e.g. RSA) those has to be retrieved out-of-band from the log's
    operators, together with the public key. This is used to verify the
    integration timestamp's value and that the log has promised to include the
    entry.
    """

    signed_entry_timestamp: bytes = betterproto.bytes_field(1)


@dataclass(eq=False, repr=False)
class TransparencyLogEntry(betterproto.Message):
    """
    TransparencyLogEntry captures all the details required from Rekor to
    reconstruct an entry, given that the payload is provided via other means.
    This type can easily be created from the existing response from Rekor.
    Future iterations could rely on Rekor returning the minimal set of
    attributes (excluding the payload) that are required for verifying the
    inclusion promise. The inclusion promise (called SignedEntryTimestamp in
    the response from Rekor) is similar to a Signed Certificate Timestamp as
    described here https://www.rfc-editor.org/rfc/rfc6962.html#section-3.2.
    """

    log_index: int = betterproto.int64_field(1)
    """The global index of the entry, used when querying the log by index."""

    log_id: "__common_v1__.LogId" = betterproto.message_field(2)
    """The unique identifier of the log."""

    kind_version: "KindVersion" = betterproto.message_field(3)
    """
    The kind (type) and version of the object associated with this entry. These
    values are required to construct the entry during verification.
    """

    integrated_time: int = betterproto.int64_field(4)
    """The UNIX timestamp from the log when the entry was persisted."""

    inclusion_promise: "InclusionPromise" = betterproto.message_field(5)
    """
    The inclusion promise/signed entry timestamp from the log. Required for
    v0.1 bundles, and MUST be verified. Optional for >= v0.2 bundles, and
    SHOULD be verified when present. Also may be used as a signed timestamp.
    """

    inclusion_proof: "InclusionProof" = betterproto.message_field(6)
    """
    The inclusion proof can be used for offline or online verification that the
    entry was appended to the log, and that the log has not been altered.
    """

    canonicalized_body: bytes = betterproto.bytes_field(7)
    """
    Optional. The canonicalized transparency log entry, used to reconstruct the
    Signed Entry Timestamp (SET) during verification. The contents of this
    field are the same as the `body` field in a Rekor response, meaning that it
    does **not** include the "full" canonicalized form (of log index, ID, etc.)
    which are exposed as separate fields. The verifier is responsible for
    combining the `canonicalized_body`, `log_index`, `log_id`, and
    `integrated_time` into the payload that the SET's signature is generated
    over. This field is intended to be used in cases where the SET cannot be
    produced determinisitically (e.g. inconsistent JSON field ordering,
    differing whitespace, etc). If set, clients MUST verify that the signature
    referenced in the `canonicalized_body` matches the signature provided in
    the `Bundle.content`. If not set, clients are responsible for constructing
    an equivalent payload from other sources to verify the signature.
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: sigstore_verification.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import (
    List,
    Optional,
)

import betterproto

from ...bundle import v1 as __bundle_v1__
from ...common import v1 as __common_v1__
from ...trustroot import v1 as __trustroot_v1__


@dataclass(eq=False, repr=False)
class CertificateIdentity(betterproto.Message):
    """The identity of a X.509 Certificate signer."""

    issuer: str = betterproto.string_field(1)
    """The X.509v3 issuer extension (OID 1.3.6.1.4.1.57264.1.1)"""

    san: "__common_v1__.SubjectAlternativeName" = betterproto.message_field(2)
    oids: List["__common_v1__.ObjectIdentifierValuePair"] = betterproto.message_field(3)
    """
    An unordered list of OIDs that must be verified. All OID/values provided in
    this list MUST exactly match against the values in the certificate for
    verification to be successful.
    """


@dataclass(eq=False, repr=False)
class CertificateIdentities(betterproto.Message):
    identities: List["CertificateIdentity"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class PublicKeyIdentities(betterproto.Message):
    public_keys: List["__common_v1__.PublicKey"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class ArtifactVerificationOptions(betterproto.Message):
    """
    A light-weight set of options/policies for identifying trusted signers,
    used during verification of a single artifact.
    """

    certificate_identities: "CertificateIdentities" = betterproto.message_field(
        1, group="signers"
    )
    public_keys: "PublicKeyIdentities" = betterproto.message_field(2, group="signers")
    """
    To simplify verification implementation, the logic for bundle verification
    should be implemented as a higher-order function, where one of argument
    should be an interface over the set of trusted public keys, like this:
    `Verify(bytes artifact, bytes signature, string key_id)`. This way the
    caller is in full control of mapping the identified (or hinted) key in the
    bundle to one of the trusted keys, as this process is inherently
    application specific.
    """

    tlog_options: Optional[
        "ArtifactVerificationOptionsTlogOptions"
    ] = betterproto.message_field(3, optional=True, group="_tlog_options")
    """
    Optional options for artifact transparency log verification. If none is
    provided, the default verification options are: Threshold: 1 Online
    verification: false Disable: false
    """

    ctlog_options: Optional[
        "ArtifactVerificationOptionsCtlogOptions"
    ] = betterproto.message_field(4, optional=True, group="_ctlog_options")
    """
    Optional options for certificate transparency log verification. If none is
    provided, the default verification options are: Threshold: 1 Detached SCT:
    false Disable: false
    """

    tsa_options: Optional[
        "ArtifactVerificationOptionsTimestampAuthorityOptions"
    ] = betterproto.message_field(5, optional=True, group="_tsa_options")
    """
    Optional options for certificate signed timestamp verification. If none is
    provided, the default verification options are: Threshold: 1 Disable: false
    """


@dataclass(eq=False, repr=False)
class ArtifactVerificationOptionsTlogOptions(betterproto.Message):
    threshold: int = betterproto.int32_field(1)
    """Number of transparency logs the entry must appear on."""

    perform_online_verification: bool = betterproto.bool_field(2)
    """Perform an online inclusion proof."""

    disable: bool = betterproto.bool_field(3)
    """Disable verification for transparency logs."""


@dataclass(eq=False, repr=False)
class ArtifactVerificationOptionsCtlogOptions(betterproto.Message):
    threshold: int = betterproto.int32_field(1)
    """The number of ct transparency logs the certificate must appear on."""

    detached_sct: bool = betterproto.bool_field(2)
    """
    Expect detached SCTs. This is not supported right now as we can't capture
    an detached SCT in the bundle.
    """

    disable: bool = betterproto.bool_field(3)
    """Disable ct transparency log verification"""


@dataclass(eq=False, repr=False)
class ArtifactVerificationOptionsTimestampAuthorityOptions(betterproto.Message):
    threshold: int = betterproto.int32_field(1)
    """The number of signed timestamps that are expected."""

    disable: bool = betterproto.bool_field(2)
    """Disable signed timestamp verification."""


@dataclass(eq=False, repr=False)
class Artifact(betterproto.Message):
    artifact_uri: str = betterproto.string_field(1, group="data")
    """Location of the artifact"""

    artifact: bytes = betterproto.bytes_field(2, group="data")
    """The raw bytes of the artifact"""


@dataclass(eq=False, repr=False)
class Input(betterproto.Message):
    """
    Input captures all that is needed to call the bundle verification method,
    to verify a single artifact referenced by the bundle.
    """

    artifact_trust_root: "__trustroot_v1__.TrustedRoot" = betterproto.message_field(1)
    """
    The verification materials provided during a bundle verification. The
    running process is usually preloaded with a "global"
    dev.sisgtore.trustroot.TrustedRoot.v1 instance. Prior to verifying an
    artifact (i.e a bundle), and/or based on current policy, some selection is
    expected to happen, to filter out the exact certificate authority to use,
    which transparency logs are relevant etc. The result should b ecaptured in
    the `artifact_trust_root`.
    """

    artifact_verification_options: "ArtifactVerificationOptions" = (
        betterproto.message_field(2)
    )
    bundle: "__bundle_v1__.Bundle" = betterproto.message_field(3)
    artifact: Optional["Artifact"] = betterproto.message_field(
        4, optional=True, group="_artifact"
    )
    """
    If the bundle contains a message signature, the artifact must be provided.
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: google/api/field_behavior.proto
# plugin: python-betterproto
from dataclasses import dataclass

import betterproto


class FieldBehavior(betterproto.Enum):
    """
    An indicator of the behavior of a given field (for example, that a field is
    required in requests, or given as output but ignored as input). This **does
    not** change the behavior in protocol buffers itself; it only denotes the
    behavior and may affect how API tooling handles the field. Note: This enum
    **may** receive new values in the future.
    """

    FIELD_BEHAVIOR_UNSPECIFIED = 0
    """Conventional default for enums. Do not use this."""

    OPTIONAL = 1
    """
    Specifically denotes a field as optional. While all fields in protocol
    buffers are optional, this may be specified for emphasis if appropriate.
    """

    REQUIRED = 2
    """
    Denotes a field as required. This indicates that the field **must** be
    provided as part of the request, and failure to do so will cause an error
    (usually `INVALID_ARGUMENT`).
    """

    OUTPUT_ONLY = 3
    """
    Denotes a field as output only. This indicates that the field is provided
    in responses, but including the field in a request does nothing (the server
    *must* ignore it and *must not* throw an error as a result of the field's
    presence).
    """

    INPUT_ONLY = 4
    """
    Denotes a field as input only. This indicates that the field is provided in
    requests, and the corresponding field is not included in output.
    """

    IMMUTABLE = 5
    """
    Denotes a field as immutable. This indicates that the field may be set once
    in a request to create a resource, but may not be changed thereafter.
    """

    UNORDERED_LIST = 6
    """
    Denotes that a (repeated) field is an unordered list. This indicates that
    the service may provide the elements of the list in any arbitrary order,
    rather than the order the user originally provided. Additionally, the
    list's order may or may not be stable.
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: sigstore_common.proto
# plugin: python-betterproto
from dataclasses import dataclass
from datetime import datetime
from typing import (
    List,
    Optional,
)

import betterproto


class HashAlgorithm(betterproto.Enum):
    """
    Only a subset of the secure hash standard algorithms are supported. See
    <https://nvlpubs.nist.gov/nistpubs/FIPS/NIST.FIPS.180-4.pdf> for more
    details. UNSPECIFIED SHOULD not be used, primary reason for inclusion is to
    force any proto JSON serialization to emit the used hash algorithm, as
    default option is to *omit* the default value of an enum (which is the
    first value, represented by '0'.
    """

    HASH_ALGORITHM_UNSPECIFIED = 0
    SHA2_256 = 1


class PublicKeyDetails(betterproto.Enum):
    """
    Details of a specific public key, capturing the the key encoding method,
    and signature algorithm. To avoid the possibility of contradicting formats
    such as PKCS1 with ED25519 the valid permutations are listed as a linear
    set instead of a cartesian set (i.e one combined variable instead of two,
    one for encoding and one for the signature algorithm).
    """

    PUBLIC_KEY_DETAILS_UNSPECIFIED = 0
    PKCS1_RSA_PKCS1V5 = 1
    """RSA"""

    PKCS1_RSA_PSS = 2
    PKIX_RSA_PKCS1V5 = 3
    PKIX_RSA_PSS = 4
    PKIX_ECDSA_P256_SHA_256 = 5
    """ECDSA"""

    PKIX_ECDSA_P256_HMAC_SHA_256 = 6
    PKIX_ED25519 = 7
    """Ed 25519"""


class SubjectAlternativeNameType(betterproto.Enum):
    SUBJECT_ALTERNATIVE_NAME_TYPE_UNSPECIFIED = 0
    EMAIL = 1
    URI = 2
    OTHER_NAME = 3
    """
    OID 1.3.6.1.4.1.57264.1.7 See
    https://github.com/sigstore/fulcio/blob/main/docs/oid-info.md#1361415726417
    --othername-san for more details.
    """


@dataclass(eq=False, repr=False)
class HashOutput(betterproto.Message):
    """
    HashOutput captures a digest of a 'message' (generic octet sequence) and
    the corresponding hash algorithm used.
    """

    algorithm: "HashAlgorithm" = betterproto.enum_field(1)
    digest: bytes = betterproto.bytes_field(2)
    """
    This is the raw octets of the message digest as computed by the hash
    algorithm.
    """


@dataclass(eq=False, repr=False)
class MessageSignature(betterproto.Message):
    """MessageSignature stores the computed signature over a message."""

    message_digest: "HashOutput" = betterproto.message_field(1)
    """
    Message digest can be used to identify the artifact. Clients MUST NOT
    attempt to use this digest to verify the associated signature; it is
    intended solely for identification.
    """

    signature: bytes = betterproto.bytes_field(2)
    """
    The raw bytes as returned from the signature algorithm. The signature
    algorithm (and so the format of the signature bytes) are determined by the
    contents of the 'verification_material', either a key-pair or a
    certificate. If using a certificate, the certificate contains the required
    information on the signature algorithm. When using a key pair, the
    algorithm MUST be part of the public key, which MUST be communicated out-
    of-band.
    """


@dataclass(eq=False, repr=False)
class LogId(betterproto.Message):
    """LogId captures the identity of a transparency log."""

    key_id: bytes = betterproto.bytes_field(1)
    """
    The unique id of the log, represented as the SHA-256 hash of the log's
    public key, calculated over the DER encoding of the key represented as
    SubjectPublicKeyInfo. See https://www.rfc-
    editor.org/rfc/rfc6962#section-3.2
    """


@dataclass(eq=False, repr=False)
class Rfc3161SignedTimestamp(betterproto.Message):
    """This message holds a RFC 3161 timestamp."""

    signed_timestamp: bytes = betterproto.bytes_field(1)
    """
    Signed timestamp is the DER encoded TimeStampResponse. See https://www.rfc-
    editor.org/rfc/rfc3161.html#section-2.4.2
    """


@dataclass(eq=False, repr=False)
class PublicKey(betterproto.Message):
    raw_bytes: Optional[bytes] = betterproto.bytes_field(
        1, optional=True, group="_raw_bytes"
    )
    """
    DER-encoded public key, encoding method is specified by the key_details
    attribute.
    """

    key_details: "PublicKeyDetails" = betterproto.enum_field(2)
    """Key encoding and signature algorithm to use for this key."""

    valid_for: Optional["TimeRange"] = betterproto.message_field(
        3, optional=True, group="_valid_for"
    )
    """Optional validity period for this key, *inclusive* of the endpoints."""


@dataclass(eq=False, repr=False)
class PublicKeyIdentifier(betterproto.Message):
    """
    PublicKeyIdentifier can be used to identify an (out of band) delivered key,
    to verify a signature.
    """

    hint: str = betterproto.string_field(1)
    """
    Optional unauthenticated hint on which key to use. The format of the hint
    must be agreed upon out of band by the signer and the verifiers, and so is
    not subject to this specification. Example use-case is to specify the
    public key to use, from a trusted key-ring. Implementors are RECOMMENDED to
    derive the value from the public key as described in RFC 6962. See:
    <https://www.rfc-editor.org/rfc/rfc6962#section-3.2>
    """


@dataclass(eq=False, repr=False)
class ObjectIdentifier(betterproto.Message):
    """An ASN.1 OBJECT IDENTIFIER"""

    id: List[int] = betterproto.int32_field(1)


@dataclass(eq=False, repr=False)
class ObjectIdentifierValuePair(betterproto.Message):
    """An OID and the corresponding (byte) value."""

    oid: "ObjectIdentifier" = betterproto.message_field(1)
    value: bytes = betterproto.bytes_field(2)


@dataclass(eq=False, repr=False)
class DistinguishedName(betterproto.Message):
    organization: str = betterproto.string_field(1)
    common_name: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class X509Certificate(betterproto.Message):
    raw_bytes: bytes = betterproto.bytes_field(1)
    """DER-encoded X.509 certificate."""


@dataclass(eq=False, repr=False)
class SubjectAlternativeName(betterproto.Message):
    type: "SubjectAlternativeNameType" = betterproto.enum_field(1)
    regexp: str = betterproto.string_field(2, group="identity")
    """A regular expression describing the expected value for the SAN."""

    value: str = betterproto.string_field(3, group="identity")
    """The exact value to match against."""


@dataclass(eq=False, repr=False)
class X509CertificateChain(betterproto.Message):
    """A chain of X.509 certificates."""

    certificates: List["X509Certificate"] = betterproto.message_field(1)
    """
    The chain of certificates, with indices 0 to n. The first certificate in
    the array must be the leaf certificate used for signing. Signers MUST NOT
    include their root CA certificates in their embedded certificate chains,
    and SHOULD NOT include intermediate CA certificates that appear in
    independent roots of trust. Verifiers MUST validate the chain carefully to
    ensure that it chains up to a root CA certificate that they trust,
    regardless of whether the chain includes additional intermediate/root CA
    certificates. Verifiers MAY enforce additional constraints, such as
    requiring that all intermediate CA certificates appear in an independent
    root of trust. Verifiers SHOULD handle old or non-complying bundles that
    have additional intermediate/root CA certificates.
    """


@dataclass(eq=False, repr=False)
class TimeRange(betterproto.Message):
    """
    The time range is closed and includes both the start and end times, (i.e.,
    [start, end]). End is optional to be able to capture a period that has
    started but has no known end.
    """

    start: datetime = betterproto.message_field(1)
    end: Optional[datetime] = betterproto.message_field(2, optional=True, group="_end")



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: sigstore_bundle.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import List

import betterproto

from .....io import intoto as ____io_intoto__
from ...common import v1 as __common_v1__
from ...rekor import v1 as __rekor_v1__


@dataclass(eq=False, repr=False)
class TimestampVerificationData(betterproto.Message):
    """
    Various timestamped counter signatures over the artifacts signature.
    Currently only RFC3161 signatures are provided. More formats may be added
    in the future.
    """

    rfc3161_timestamps: List[
        "__common_v1__.Rfc3161SignedTimestamp"
    ] = betterproto.message_field(1)
    """
    A list of RFC3161 signed timestamps provided by the user. This can be used
    when the entry has not been stored on a transparency log, or in conjunction
    for a stronger trust model. Clients MUST verify the hashed message in the
    message imprint against the signature in the bundle.
    """


@dataclass(eq=False, repr=False)
class VerificationMaterial(betterproto.Message):
    """
    VerificationMaterial captures details on the materials used to verify
    signatures.
    """

    public_key: "__common_v1__.PublicKeyIdentifier" = betterproto.message_field(
        1, group="content"
    )
    x509_certificate_chain: "__common_v1__.X509CertificateChain" = (
        betterproto.message_field(2, group="content")
    )
    tlog_entries: List["__rekor_v1__.TransparencyLogEntry"] = betterproto.message_field(
        3
    )
    """
    An inclusion proof and an optional signed timestamp from the log. Client
    verification libraries MAY provide an option to support v0.1 bundles for
    backwards compatibility, which may contain an inclusion promise and not an
    inclusion proof. In this case, the client MUST validate the promise.
    Verifiers SHOULD NOT allow v0.1 bundles if they're used in an ecosystem
    which never produced them.
    """

    timestamp_verification_data: "TimestampVerificationData" = (
        betterproto.message_field(4)
    )
    """
    Timestamp may also come from
    tlog_entries.inclusion_promise.signed_entry_timestamp.
    """


@dataclass(eq=False, repr=False)
class Bundle(betterproto.Message):
    media_type: str = betterproto.string_field(1)
    """
    MUST be application/vnd.dev.sigstore.bundle+json;version=0.1 or
    application/vnd.dev.sigstore.bundle+json;version=0.2 when encoded as JSON.
    """

    verification_material: "VerificationMaterial" = betterproto.message_field(2)
    """
    When a signer is identified by a X.509 certificate, a verifier MUST verify
    that the signature was computed at the time the certificate was valid as
    described in the Sigstore client spec: "Verification using a Bundle". <http
    s://docs.google.com/document/d/1kbhK2qyPPk8SLavHzYSDM8-Ueul9_oxIMVFuWMWKz0E
    /edit#heading=h.x8bduppe89ln>
    """

    message_signature: "__common_v1__.MessageSignature" = betterproto.message_field(
        3, group="content"
    )
    dsse_envelope: "____io_intoto__.Envelope" = betterproto.message_field(
        4, group="content"
    )
    """
    A DSSE envelope can contain arbitrary payloads. Verifiers must verify that
    the payload type is a supported and expected type. This is part of the DSSE
    protocol which is defined here: <https://github.com/secure-systems-
    lab/dsse/blob/master/protocol.md>
    """
